@@ -773,6 +773,15 @@ get_acs <- function(geography, variables = NULL, table = NULL, cache_table = FAL
 
   }
 
+  # For ZCTAs, strip the state code from GEOID (issue #338 and #358)
+  # Should only happen if the GEOID is 7 characters
+  if (geography == "zip code tabulation area" && year > 2012 && unique(nchar(dat2$GEOID)) == 7) {
+    dat2 <- dat2 %>%
+      dplyr::mutate(
+        GEOID = stringr::str_sub(GEOID, start = 3L)
+      )
+  }
+
   if (!is.null(summary_var)) {
 
     if (length(summary_var) > 1) {
@@ -789,6 +798,13 @@ get_acs <- function(geography, variables = NULL, table = NULL, cache_table = FAL
 
     summoe <- paste0(summary_var, "M")
 
+    if (geography == "zip code tabulation area" && year > 2012 && unique(nchar(sumdat$GEOID)) == 7) {
+      sumdat <- sumdat %>%
+        dplyr::mutate(
+          GEOID = stringr::str_sub(GEOID, start = 3L)
+        )
+    }
+
     dat2 <- dat2 %>%
       inner_join(sumdat, by = "GEOID") %>%
       rename(summary_est = !! sumest,
@@ -809,13 +825,6 @@ get_acs <- function(geography, variables = NULL, table = NULL, cache_table = FAL
     dat2[dat2 == -999999999] <- NA
   }
 
-  # For ZCTAs, strip the state code from GEOID (issue #338 and #358)
-  if (geography == "zip code tabulation area" && (year > 2012 && year < 2020)) {
-    dat2 <- dat2 %>%
-      dplyr::mutate(
-        GEOID = stringr::str_sub(GEOID, start = 3L)
-      )
-  }
 
   # If multiple ZCTAs are requested for multiple states, handle the filtering here
   if (!is.null(zips_to_get)) {
